@@ -16,10 +16,9 @@
 #include <string>
 #include <utility>
 
-#include "nlohmann/json.hpp"
-
-#include "xguid.hpp"
-#include "xmessage.hpp"
+#include "xeus/xguid.hpp"
+#include "xeus/xjson.hpp"
+#include "xeus/xmessage.hpp"
 
 namespace nl = nlohmann;
 
@@ -282,8 +281,7 @@ namespace xeus
         content["comm_id"] = m_id;
         content["target_name"] = target_name;
         content["data"] = std::move(data);
-        target().publish_message(
-            msg_type, std::move(metadata), std::move(content), std::move(buffers));
+        target().publish_message(msg_type, std::move(metadata), std::move(content), std::move(buffers));
     }
 
     inline xcomm::xcomm(xcomm&& comm)
