@@ -10,9 +10,8 @@
 #ifndef XEUS_CONTROL_MESSENGER_HPP
 #define XEUS_CONTROL_MESSENGER_HPP
 
-#include "nlohmann/json.hpp"
-
 #include "xeus/xeus.hpp"
+#include "xeus/xjson.hpp"
 
 namespace nl = nlohmann;
 
