@@ -23,7 +23,10 @@ namespace xeus
         if (p_manager->p_kernel != nullptr)
         {
             p_manager->p_kernel->publish_message(
-                msg_type, std::move(metadata), std::move(content), std::move(buffers), channel::SHELL);
+                msg_type, p_manager->p_kernel->parent_header(),
+                std::move(metadata), std::move(content), 
+                std::move(buffers), channel::SHELL
+            );
         }
     }
 
@@ -73,10 +76,9 @@ namespace xeus
             if (p_kernel != nullptr)
             {
                 p_kernel->publish_message(
-                    "comm_close", nl::json::object(), std::move(content), buffer_sequence(), channel::SHELL
+                    "comm_close", request.header(), nl::json::object(), std::move(content), buffer_sequence(), channel::SHELL
                 );
             }
-            throw std::runtime_error("No such comm target registered: " + target_name);
         }
         else
         {
