@@ -7,6 +7,7 @@
 * The full license is in the file LICENSE, distributed with this software. *
 ****************************************************************************/
 
+#include <iostream>
 #include <string>
 #include <random>
 
@@ -146,6 +147,7 @@ namespace xeus
                                                 p_history_manager.get(),
                                                 p_debugger.get());
 
+        std::cout << "Core instantiated" << std::endl;
         xcontrol_messenger& messenger = p_server->get_control_messenger();
 
         if(p_debugger != nullptr)
